@@ -2,15 +2,17 @@
 library("msaenet")
 
 ## ------------------------------------------------------------------------
-dat = msaenet.sim.gaussian(n = 150, p = 500, rho = 0.7,
-                           coef = rep(1, 5), snr = 3, p.train = 0.7,
-                           seed = 1001)
+dat = msaenet.sim.gaussian(
+  n = 150, p = 500, rho = 0.7,
+  coef = rep(1, 5), snr = 3, p.train = 0.7,
+  seed = 1001)
 
 ## ------------------------------------------------------------------------
-msaenet.fit = msaenet(dat$x.tr, dat$y.tr,
-                      alphas = seq(0.1, 0.9, 0.1),
-                      nsteps = 10L, tune.nsteps = "ebic",
-                      seed   = 1005)
+msaenet.fit = msaenet(
+  dat$x.tr, dat$y.tr,
+  alphas = seq(0.1, 0.9, 0.1),
+  nsteps = 10L, tune.nsteps = "ebic",
+  seed   = 1005)
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  library(doParallel)
